/* Schedwi
   Copyright (C) 2013, 2014 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* schedwi_system.h -- system() with environment variables */

#ifndef _SCHEDWI_SYSTEM_H
#define _SCHEDWI_SYSTEM_H

#include <schedwi.h>

/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int schedwi_system OF((	const char *command,
				const char *workload_jobid,
				const char *job_name_with_path,
				const char * const *variables, size_t len));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* schedwi_system.h */

/*-----------------============== End Of File ==============-----------------*/
